@@ -31,7 +31,7 @@ class HTTPBackend(object):
 
     @FIXME: Build in support for supplying arbitrary backends
     """
-    def __init__(self, api_key, as_xml=False, resource_name=None):
+    def __init__(self, api_key, as_xml=False, resource_name=None, timeout=None):
         """
         Creates an HTTPBackend object, which abstracts out some of the
         library specific HTTP stuff.
@@ -41,7 +41,7 @@ class HTTPBackend(object):
             self.base_url = self.base_url + resource_name
 
         #TODO investigate httplib2 caching and if it is necessary
-        self.http = httplib2.Http()
+        self.http = httplib2.Http(timeout=timeout)
         self.as_xml = as_xml
         self.api_key = api_key
 
@@ -72,6 +72,35 @@ class HTTPBackend(object):
                 return None
             else:
                 return json.loads(raw_body)
+        else:
+            raise NotImplementedError('Decoding as XML is not supported.')
+
+    def delete(self, url, params=None):
+        """
+        Executes an HTTP DELETE request for the given URL
+
+        params should be a urllib.urlencoded string
+        """
+        if params:
+            url = '?'.join([url, params])
+
+        response, content = self.http.request(url, method="DELETE",
+                                              headers=self.headers)
+        return self.process(response, content)
+
+    def get(self, url, data=None):
+        """
+        Executes an HTTP GET request for the given URL
+
+        data should be a dictionary of url parameters
+        """
+        if data:
+            params = urlencode(data)
+            url = '?'.join([url, params])
+
+        response, content = self.http.request(url, method="GET",
+                                              headers=self.headers)
+        return self.process(response, content)
 
     def post(self, url, body=None):
         """
@@ -83,19 +112,6 @@ class HTTPBackend(object):
 
         return self.process(response, content)
 
-    def get(self, url, params=None):
-        """
-        Executes an HTTP GET request for the given URL
-
-        params should be a urllib.urlencoded string
-        """
-        if params:
-            url = '?'.join([url, params])
-
-        response, content = self.http.request(url, method="GET",
-                                              headers=self.headers)
-        return self.process(response, content)
-
     def process(self, http_response, content):
         """
         Returns HTTP backend agnostic Response data
@@ -107,7 +123,7 @@ class HTTPBackend(object):
 
 class Zencoder(object):
     """ This is the entry point to the Zencoder API """
-    def __init__(self, api_key=None, as_xml=False):
+    def __init__(self, api_key=None, as_xml=False, timeout=None):
         """
         Initializes Zencoder. You must have a valid API_KEY.
 
@@ -127,9 +143,9 @@ class Zencoder(object):
             self.api_key = api_key
 
         self.as_xml = as_xml
-        self.job = Job(self.api_key, self.as_xml)
-        self.account = Account(self.api_key, self.as_xml)
-        self.output = Output(self.api_key, self.as_xml)
+        self.job = Job(self.api_key, self.as_xml, timeout=timeout)
+        self.account = Account(self.api_key, self.as_xml, timeout=timeout)
+        self.output = Output(self.api_key, self.as_xml, timeout=timeout)
 
 class Response(object):
     """
@@ -144,11 +160,11 @@ class Response(object):
 
 class Account(HTTPBackend):
     """ Account object """
-    def __init__(self, api_key=None, as_xml=False):
+    def __init__(self, api_key=None, as_xml=False, timeout=None):
         """
         Initializes an Account object
         """
-        super(Account, self).__init__(api_key, as_xml, 'account')
+        super(Account, self).__init__(api_key, as_xml, 'account', timeout=timeout)
 
     def create(self, email, tos=True, options=None):
         """
@@ -167,7 +183,7 @@ class Account(HTTPBackend):
         """
         data = {'api_key': self.api_key}
 
-        return self.get(self.base_url, params=urlencode(data))
+        return self.get(self.base_url, data=data)
 
     def integration(self):
         """
@@ -175,8 +191,7 @@ class Account(HTTPBackend):
         """
         data = {'api_key': self.api_key}
 
-        return self.get(self.base_url + '/integration',
-                        params=urlencode(data))
+        return self.get(self.base_url + '/integration', data=data)
 
     def live(self):
         """
@@ -184,16 +199,15 @@ class Account(HTTPBackend):
         """
         data = {'api_key': self.api_key}
 
-        return self.get(self.base_url + '/live',
-                        params=urlencode(data))
+        return self.get(self.base_url + '/live', data=data)
 
 class Output(HTTPBackend):
     """ Gets information regarding outputs """
-    def __init__(self, api_key, as_xml=False):
+    def __init__(self, api_key, as_xml=False, timeout=None):
         """
         Contains all API methods relating to Outputs.
         """
-        super(Output, self).__init__(api_key, as_xml, 'outputs')
+        super(Output, self).__init__(api_key, as_xml, 'outputs', timeout=timeout)
 
     def progress(self, output_id):
         """
@@ -201,17 +215,17 @@ class Output(HTTPBackend):
         """
         data = {'api_key': self.api_key}
         return self.get(self.base_url + '/%s/progress' % str(output_id),
-                        params=urlencode(data))
+                        data=data)
 
 class Job(HTTPBackend):
     """
     Contains all API methods relating to transcoding Jobs.
     """
-    def __init__(self, api_key, as_xml=False):
+    def __init__(self, api_key, as_xml=False, timeout=None):
         """
         Initialize a job object
         """
-        super(Job, self).__init__(api_key, as_xml, 'jobs')
+        super(Job, self).__init__(api_key, as_xml, 'jobs', timeout=timeout)
 
     def create(self, input, outputs=None, options=None):
         """
@@ -237,29 +251,34 @@ class Job(HTTPBackend):
         data = {"api_key": self.api_key,
                 "page": page,
                 "per_page": per_page}
-        return self.get(self.base_url, params=urlencode(data))
+        return self.get(self.base_url, data=data)
 
     def details(self, job_id):
         """
-        Get some job details
+        Gets details for the given job
         """
-        pass
+        data = {'api_key': self.api_key}
+        return self.get(self.base_url + '/%s' % str(job_id), data=data)
 
     def resubmit(self, job_id):
         """
         Resubmits a job
         """
-        pass
+        data = {'api_key': self.api_key}
+        return self.get(self.base_url + '/%s/resubmit' % str(job_id), data=data)
 
     def cancel(self, job_id):
         """
         Cancels a job
         """
-        pass
+        data = {'api_key': self.api_key}
+        return self.get(self.base_url + '/%s/cancel' % str(job_id), data=data)
 
     def delete(self, job_id):
         """
         Deletes a job
         """
-        pass
+        data = {'api_key': self.api_key}
+        return self.delete(self.base_url + '/%s' % str(job_id),
+                        params=urlencode(data))
 
